@@ -3,6 +3,7 @@ package runner
 import (
 	"fmt"
 	"io"
+	"log"
 	"os"
 	"os/exec"
 	"path/filepath"
@@ -77,7 +78,11 @@ func NewEngine(cfgPath string, debugMode bool) (*Engine, error) {
 // Run run run
 func (e *Engine) Run() {
 	if len(os.Args) > 1 && os.Args[1] == "init" {
-		writeDefaultConfig()
+		configName, err := writeDefaultConfig()
+		if err != nil {
+			log.Fatalf("Failed writing default config: %+v", err)
+		}
+		fmt.Printf("%s file created to the current directory with the default settings\n", configName)
 		return
 	}
 
@@ -539,10 +544,25 @@ func (e *Engine) runBin() error {
 					go killFunc(cmd, stdout, stderr, killCh, processExit, &wg)
 				})
 
-				_, _ = io.Copy(os.Stdout, stdout)
-				_, _ = io.Copy(os.Stderr, stderr)
-				_, _ = cmd.Process.Wait()
+				go func() {
+					_, _ = io.Copy(os.Stdout, stdout)
+					_, _ = cmd.Process.Wait()
+				}()
+
+				go func() {
+					_, _ = io.Copy(os.Stderr, stderr)
+					_, _ = cmd.Process.Wait()
+				}()
+				state, _ := cmd.Process.Wait()
 				close(processExit)
+				switch state.ExitCode() {
+				case 0:
+					e.runnerLog("Process Exit with Code 0")
+				case -1:
+					// because when we use ctrl + c to stop will return -1
+				default:
+					e.runnerLog("Process Exit with Code: %v", state.ExitCode())
+				}
 
 				if !e.config.Build.Rerun {
 					return
